<?php



class BucketBlazeUpdater{


	private $updateInfoUrl;
	private $pluginSlug;
	private $pluginFile;
	private $version;
	/**
	 * PluginUpdater constructor.
	 */
	public function __construct() {

		$this->updateInfoUrl = 'https://bucketblaze.com/bucketblaze_downloads_plugin/info.json';
		$this->pluginSlug = 'bucketblaze-downloads';
		$this->pluginFile = 'bucketblaze-downloads/bucketblaze-downloads.php';
		$this->version = '0.0.5';

		add_filter('plugins_api', array(&$this, 'pluginInfo'), 20, 3);
		add_filter('site_transient_update_plugins', array(&$this, 'pushUpdate') );
		add_action('upgrader_process_complete', array(&$this, 'afterUpdate'), 10, 2 );

	}


	/*
 * $res empty at this step
 * $action 'plugin_information'
 * $args stdClass Object ( [slug] => woocommerce [is_ssl] => [fields] => Array ( [banners] => 1 [reviews] => 1 [downloaded] => [active_installs] => 1 ) [per_page] => 24 [locale] => en_US )
 */
	public function pluginInfo( $res, $action, $args ){

		// do nothing if this is not about getting plugin information
		if( 'plugin_information' !== $action ) {
			return false;
		}

		// do nothing if it is not our plugin
		if( $this->pluginSlug!== $args->slug ) {
			return false;
		}

		// trying to get from cache first
		if( false == $remote = get_transient( 'update_' . $this->pluginSlug ) ) {

			// info.json is the file with the actual plugin information on your server
			$remote = wp_remote_get( $this->updateInfoUrl, array(
					'timeout' => 10,
					'headers' => array(
						'Accept' => 'application/json'
					) )
			);

			if ( ! is_wp_error( $remote ) && isset( $remote['response']['code'] ) && $remote['response']['code'] == 200 && ! empty( $remote['body'] ) ) {
				set_transient( 'update_' . $this->pluginSlug, $remote, 10 ); // 12 hours cache
			}

		}

		if( ! is_wp_error( $remote ) && isset( $remote['response']['code'] ) && $remote['response']['code'] == 200 && ! empty( $remote['body'] ) ) {

			$remote = json_decode( $remote['body'] );
			$res = new stdClass();

			$res->name = $remote->name;
			$res->slug = $this->pluginSlug;
			$res->version = $remote->version;
			$res->tested = $remote->tested;
			$res->requires = $remote->requires;
			$res->author = '<a href="https://bucketblaze.com">BucketBlaze.com</a>';
			//$res->author_profile = 'https://profiles.wordpress.org/#';
			$res->download_link = $remote->download_url;
			$res->trunk = $remote->download_url;
			$res->requires_php = $remote->requires_php;;
			$res->last_updated = $remote->last_updated;
			$res->sections = array(
				'description' => $remote->sections->description,
				'installation' => $remote->sections->installation,
				'changelog' => $remote->sections->changelog
				// you can add your custom sections (tabs) here
			);

			// in case you want the screenshots tab, use the following HTML format for its content:
			// <ol><li><a href="IMG_URL" target="_blank"><img src="IMG_URL" alt="CAPTION" /></a><p>CAPTION</p></li></ol>
			if( !empty( $remote->sections->screenshots ) ) {
				$res->sections['screenshots'] = $remote->sections->screenshots;
			}

			//$res->banners = $remote->banners;

			$res->banners = array(
				"low" => "https://bucketblaze.com/bucketblaze_downloads_plugin/banner-772x250.png",
                "high" => "https://bucketblaze.com/bucketblaze_downloads_plugin/banner-1544x500.png"
			);
			return $res;

		}

		return false;

	}


	public function pushUpdate( $transient ){

		if ( empty($transient->checked ) ) {
			return $transient;
		}

		// trying to get from cache first, to disable cache comment 10,20,21,22,24
		if( false == $remote = get_transient( "upgrade_{$this->pluginSlug}" ) ) {

			// info.json is the file with the actual plugin information on your server
			$remote = wp_remote_get( $this->updateInfoUrl, array(
					'timeout' => 10,
					'headers' => array(
						'Accept' => 'application/json'
					) )
			);

			if ( !is_wp_error( $remote ) && isset( $remote['response']['code'] ) && $remote['response']['code'] == 200 && !empty( $remote['body'] ) ) {
				set_transient( "upgrade_{$this->pluginSlug}", $remote, 43200 ); // 12 hours cache
			}

		}

		if( $remote ) {

			$remote = json_decode( $remote['body'] );

			// your installed plugin version should be on the line below! You can obtain it dynamically of course
			if( $remote && version_compare( $this->version, $remote->version, '<' ) && version_compare($remote->requires, get_bloginfo('version'), '<' ) ) {
				$res = new stdClass();
				$res->slug = $this->pluginSlug;
				$res->plugin = $this->pluginFile;
				$res->new_version = $remote->version;
				$res->tested = $remote->tested;
				$res->package = $remote->download_url;
				$transient->response[$res->plugin] = $res;
				//$transient->checked[$res->plugin] = $remote->version;
			}

		}
		return $transient;
	}


	public function afterUpdate( $upgrader_object, $options ) {
		if ( $options['action'] == 'update' && $options['type'] === 'plugin' )  {
			// just clean the cache when new plugin version is installed
			delete_transient( "upgrade_{$this->pluginSlug}" );
		}
	}


}


if ( is_admin() )
	$bucketblaze_updater = new BucketBlazeUpdater();



