<?php
/*
Plugin Name: BucketBlaze Downloads
Plugin URI: https://bucketblaze.com
Description: Converts S3 urls to bucketblaze urls
Version: 0.0.5
Author: BucketBlaze
Author URI: https://bucketblaze.com
License: GPLv2 or later
License URI: http://www.gnu.org/licenses/gpl-2.0.html
*/


/* TODO:

- dashboard i admin - shortcode generator - konverzija s3 linka u shortcode
- plugin info in wordpress (details and update)
- support custom expiry parameter ?
*/
class BucketBlazeDownloads{

	private $config;

	public function __construct() {

		require_once 'BucketBlazeOptions.php';
		require_once 'BucketBlazeUpdater.php';
		//Shortcode
		add_shortcode( 'bucketblaze_download', array( &$this, 'downloadFileShortcode' ) );
		// Run the download path through do_shortcode
		add_filter( 'woocommerce_file_download_paths', array( &$this, 'downloadFilePathFilter' ) );
		add_filter( 'woocommerce_product_file_download_path', array( &$this, 'downloadFilePathFilter' ) );

		/*
		$config = array(
			'sendowl-hw-test' => array(
				'secret' => "zuJQhqKgYF=H@d_VdT#@9FwwY3JyeT",
				'signing_key' => ";;sEP;:yyZcwMb~QF~d&ZUfx6H!44n",
				'baseLambdaUrl' => "https://97kim662zc.execute-api.us-east-1.amazonaws.com",
				'customerId' => "BucketBlazeDEV"
			)
		);
		*/
		//$this->storeConfiguration($config);

		$this->loadConfiguration();

	}

	private function storeConfiguration($config){
		update_option( 'bucketblaze_downloads_config', $config, $autoload = false );
	}

	private function loadConfiguration(){
		$this->config = get_option('bucketblaze_downloads_config');

	}

	public function downloadFilePathFilter($path){
		return do_shortcode( $path );
	}

	public function downloadFileShortcode( $atts ) {

		extract( shortcode_atts( array(
			'bucket' => false,
			'path'   => false,
			'object' => false,
			'expiry' => 2
		), $atts ) );

		if ( ! $bucket || (!$path && !$object )) {
			return '';
		}
		// Support for different path name (woocommerce w3 plugin compatibility)
		if(!$path){
			$path = $object;
		}

		//return $this->generate_download_url( $bucket, $path, $expiry );
		return $this->createSignedUrl($bucket, $path, $expiry);
	}

	private function createSignedUrl($bucket, $s3FilePath, $expiry){
		$exp = strtotime("+2 minutes");

		$conf = $this->config[$bucket];
		if(empty($conf)){
			return 'BucketBlaze error: Missing configuration!';
		}
		$text = "exp=$exp&secret={$conf['secret']}";
		$sig = hash_hmac('sha256', $text, "{$conf['signing_key']}&{$conf['secret']}", true);
		$signature =  urlencode(base64_encode($sig));

		return "{$conf['baseLambdaUrl']}/{$conf['customerId']}/$s3FilePath?exp=$exp&signature=$signature&source=wp";
	}
}


$bucketBlazeDownloads = new BucketBlazeDownloads();
